@@ -3,8 +3,14 @@
 use strict ;
 use URI::ParseSearchString ;
 
+my $uparse = new URI::ParseSearchString ;
+
 my $ref_str = 'http://www.google.com/search?hl=en&q=this+is+an+example&btnG=Google+Search' ;
 
-my $keywords = parse_search_string($ref_str) ;
+my $keywords = $uparse->parse_search_string($ref_str) ;
 
-print "The keywords were: $keywords \n" ;
\ No newline at end of file
+print "The keywords were: $keywords \n" ;
+
+my $engine = $uparse->findEngine($ref_str) ;
+
+print "The engine was: $engine \n" ;
\ No newline at end of file
